Name:           ensmallen
Version:        2.10.3
Release:        1%{?dist}
Summary:        Header-only C++ library for efficient mathematical optimization

License:        BSD
URL:            https://www.ensmallen.org
Source0:        https://www.ensmallen.org/files/%{name}-%{version}.tar.gz

BuildRequires:  cmake >= 2.8.5
BuildRequires:	gcc-c++
BuildRequires:	armadillo-devel >= 8.400.0
Requires:       armadillo-devel >= 8.400.0

Patch0:         random_tests.patch

# ensmallen is header-only, and the build just builds the tests, so there's no
# use for a debuginfo package.
%global debug_package %{nil}

%description
ensmallen is a header-only C++ library for efficient mathematical optimization.
It provides a simple set of abstractions for writing an objective function to
optimize. It also provides a large set of standard and cutting-edge optimizers
that can be used for virtually any mathematical optimization task.  These
include full-batch gradient descent techniques, small-batch techniques,
gradient-free optimizers, and constrained optimization.

%prep
%autosetup -p1

%build
%cmake

# Technically we don't need to build anything but it's a good sanity check to
# just build the tests to make sure they compile.
%make_build

%install
%make_install

%check
# Disable the SmallLovaszThetaSdp test---it exposes a bug in one of ensmallen's
# dependencies.  In addition, sometimes the tests may fail, as they are
# probabilistic---so just make sure the test suite passes at least once out of
# five runs.
%ifarch armv7hl
# There's an issue with the tests on armv7hl.
%else
success=0;
for i in `seq 1 5`; do
  ./ensmallen_tests ~SmallLovaszThetaSdp
  if [ $? -eq 0 ]; then
    success=1;
    break;
  fi
done
if [ $success -eq 0 ]; then
  perl -e "die()" # Force a build error.
fi
%endif

%package devel
Summary:  Header-only C++ library for efficient mathematical optimization
Provides: ensmallen-static = %{version}-%{release}

%description devel
ensmallen is a header-only C++ library for efficient mathematical optimization.
It provides a simple set of abstractions for writing an objective function to
optimize. It also provides a large set of standard and cutting-edge optimizers
that can be used for virtually any mathematical optimization task.  These
include full-batch gradient descent techniques, small-batch techniques,
gradient-free optimizers, and constrained optimization.

%files devel
%license LICENSE.txt
%{_includedir}/ensmallen.hpp
%{_includedir}/ensmallen_bits/

%changelog
* Thu Sep 26 2019 Ryan Curtin <ryan@ratml.org> - 2.10.3-1
- Update to latest stable version.

* Wed Sep 11 2019 Ryan Curtin <ryan@ratml.org> - 2.10.2-1
- Update to latest stable version.

* Fri Aug 16 2019 Ryan Curtin <ryan@ratml.org> - 1.16.2-1
- Update to latest stable version.

* Wed Jul 24 2019 Fedora Release Engineering <releng@fedoraproject.org> - 1.15.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Mon May 27 2019 Ryan Curtin <ryan@ratml.org> - 1.15.1-1
- Update to latest stable version.

* Mon May  6 2019 Ryan Curtin <ryan@ratml.org> - 1.14.2-1
- Initial packaging.
